@@ -19,7 +19,7 @@ import pandas as pd
 from termcolor import cprint
 from inspect import currentframe
 
-__version__ = '0.1.26'
+__version__ = '0.1.27'
 
 __info__ = {
     '2022/01/04: 0.1.18 加入 __info__。',
@@ -610,13 +610,15 @@ class tplaysound(threading.Thread):
         self.start()
 
 
+    def play(self, filename=None):
+        self.play_file(filename=filename)
 
     def play_file(self, filename=None):
         if filename is None:
             filename = self.sound_alert
         command = ('play', filename)
         self.queue.put(command)
-        print(f'send command {command}')
+        # print(f'send command {command}')
 
     def run(self):
         while True:
@@ -629,12 +631,12 @@ class tplaysound(threading.Thread):
                     break
 
                 if cmd == 'play':
-                    print('got Play')
+                    # print('got Play')
                     if os.name == 'nt':
-                        print('NT play')
+                        # print('NT play')
                         winsound.PlaySound(arg, winsound.SND_FILENAME)
                     else:
-                        print('POSIX play')
+                        # print('POSIX play')
                         playsound(arg)
 
     def stop(self):
